diff --git a/geomagio/algorithm/SpikesAlgorithm.py b/geomagio/algorithm/SpikesAlgorithm.py
index 326adb1ed424a32f4ff91e4ca6a6006e9c35fb64..5a4cfa19ae606ebb277569bbf445d879a7f98d0f 100644
--- a/geomagio/algorithm/SpikesAlgorithm.py
+++ b/geomagio/algorithm/SpikesAlgorithm.py
@@ -18,13 +18,13 @@ class SpikesAlgorithm(MetadataAlgorithm):
     Attributes
     ----------
     window_size: int
         Size of the rolling window for dynamic alignment (no shrinking or padding).
     threshold: int
-        Threshold for spike detection (threshold * sigma).
+        Threshold for spike detection (threshold * sigma). Defaults to 6.
     """
 
-    window_size: int
-    threshold: int
+    window_size: Optional[int] = 1000
+    threshold: Optional[int] = 6
 
     def _despike(
         self, signal: Trace, timestamps: List[UTCDateTime]
@@ -18,13 +18,13 @@ class SpikesAlgorithm(MetadataAlgorithm):
     ----------
     window_size: int
-        Size of the rolling window for dynamic alignment (no shrinking or padding).
+        Size of the rolling window for dynamic alignment (no shrinking or padding). Defaults to 1000.
     threshold: int